Platform class

Constructors

Platform({bool? enabled = false, required String path, bool? fallback = false})

Properties

canFall → bool
no setter
enabled → bool?
final
fallback → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited