Platforms class

Constructors

Platforms({Platform? linux, Platform? windows, Platform? macos})

Properties

hasAnyPlatform → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasLinux → bool
no setter
hasMacos → bool
no setter
hasWindows → bool
no setter
linux → Platform?
final
macos → Platform?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windows → Platform?
final

Methods

all() → String
Helper to get a list of enabled platforms for logging
canFallback() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited